# -*- coding: utf-8 -*-

from django import forms
from django.forms import widgets
from django.conf import settings
from django.template.loader import render_to_string
from django.utils.safestring import mark_safe


class LocationWidget(widgets.TextInput):

    def render(self, name, value, attrs=None):
        text_input = super(LocationWidget, self).render(name, value, attrs)

        return render_to_string('djplaces/map_widget.html', {
            'field_name': name,
            'field_input': mark_safe(text_input)
        })

    def _media(self):
        return forms.Media(
                    css={'all': ('css/djplaces.css',)},
                    js=(
                        settings.JQUERY_URL,
                        settings.GOOGLE_PLACES_URL,
                        settings.GEOCOMPLETE_URL,
                        'js/djplaces.js'
                        )
                )
    media = property(_media)




# -*- coding: utf-8 -*-

from django.db.models import CharField
from django.core.exceptions import ImproperlyConfigured
from django.utils.translation import ugettext_lazy as _

from .widgets import LocationWidget


class LocationField(CharField):
    description = _("A geoposition field (latitude and longitude)")

    def __init__(self, base_field=None, *args, **kwargs):
        self.base_field = base_field
        kwargs['max_length'] = 63
        super(LocationField, self).__init__(*args, **kwargs)

    def deconstruct(self):
        name, path, args, kwargs = super(LocationField, self).deconstruct()
        del kwargs["max_length"]

        if self.base_field == '':
            raise ImproperlyConfigured()
        return name, path, args, kwargs

    def formfield(self, **kwargs):
        kwargs['widget'] = LocationWidget
        return super(LocationField, self).formfield(**kwargs)
